@@ -145,85 +145,6 @@ class OpenEuler():
     def __init__(self):
         pass
 
-    def __replace_macros(self,value, macros):
-        """根据宏字典替换字符串中的宏."""
-        if not macros:
-            return value
-
-            # 预编译所有宏的正则表达式，提升效率
-        patterns = [
-            (re.compile(re.escape(key)), val)
-            for key, val in macros.items()
-        ]
-
-        prev_value = None
-        current_value = value
-        # 循环替换直到无变化（处理嵌套宏）
-        index = 0
-        while current_value != prev_value:
-            index+=1
-            if index>=10:
-                break
-            prev_value = current_value
-            for pattern, replacement in patterns:
-                try:
-                    current_value = pattern.sub(replacement, current_value)
-                except Exception as e:
-                    continue
-        return current_value
-
-
-    def __extract_macros(self,spec):
-        macros = dict(spec.macros)
-
-        # 补充必要的默认宏（若不存在）
-        macros.setdefault("name", spec.name)
-        macros.setdefault("version", spec.version)
-        macros.setdefault("release", spec.release)
-
-        # 补充全局默认宏（若不存在）
-        for key, default_val in DEFAULT_MACROS.items():
-            macros.setdefault(key, default_val)
-
-        return macros
-
-
-    def __get_rpm_list_from_spec(self,spec_file):
-        """从 RPM spec 文件中提取所有包名并替换宏。"""
-        spec = Spec.from_file(spec_file)
-        rpm_list = []
-        macros = self.__extract_macros(spec)
-
-        # 提取子包名称
-        for pkg in spec.packages:
-            subpackage_name = self.__replace_macros(pkg.name, macros)
-            if subpackage_name not in rpm_list:
-                if "%" in subpackage_name:
-                    log.warning(f"{subpackage_name} contains macro, please check")
-                else:
-                    rpm_list.append(subpackage_name)
-
-        return rpm_list
-
-    def get_openEuler_rpm_names_from_repo(self,os_version,repo_name,repo_url):
-        branch=f"openEuler-{os_version}"
-        rpm_list = []
-        with tempfile.TemporaryDirectory() as temp_dir:
-            try:
-                git.Repo.clone_from(repo_url, temp_dir, branch=branch, depth=1)
-                log.info(f"clone {repo_name} success")
-            except Exception as e:
-                log.error(f"clone {repo_name} failed, error is {e}")
-                return rpm_list
-            spec_files = list(Path(temp_dir).rglob("*.spec"))
-
-            for spec_file in spec_files:
-                temp_list = self.__get_rpm_list_from_spec(spec_file)
-                for elem in temp_list:
-                    if elem not in rpm_list:
-                        rpm_list.append(elem)
-        return rpm_list
-
     def get_openEuler_repo_names_and_urls(
             self,
             os_version: str
